"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getAllApps = getAllApps;
exports.getApps = getApps;
exports.getUpiApps = getUpiApps;
exports.multiply = multiply;

var _reactNative = require("react-native");

const LINKING_ERROR = `The package 'react-native-get-apps' doesn't seem to be linked. Make sure: \n\n` + _reactNative.Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo managed workflow\n';
const GetApps = _reactNative.NativeModules.GetApps ? _reactNative.NativeModules.GetApps : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }

});

function multiply(a, b) {
  return GetApps.multiply(a, b);
}

async function getAllApps() {
  if (_reactNative.Platform.OS === 'android') return GetApps.getAllApps();
  return getAppsArray(await GetApps.getApps());
}

async function getApps() {
  if (_reactNative.Platform.OS === 'android') return GetApps.getApps();
  return getAppsArray(await GetApps.getApps()).filter(item => !item.packageName.startsWith('com.apple.'));
}

async function getUpiApps() {
  if (_reactNative.Platform.OS === 'android') return GetApps.getUpiApps();
  return getAppsArray(await GetApps.getApps()).filter(() => false);
}

const getAppsArray = stream => {
  if (!stream) return [];
  const regex = /> .* file/;
  stream = stream.slice(1, -1);
  const pList = stream.split(',');
  const resultArray = [];

  for (const item of pList) {
    let packageName = '';
    let idx = item.search(regex);
    if (idx === -1) continue;
    idx = idx + 2;

    while (idx < item.length && item[idx] !== ' ') packageName += item[idx], idx += 1;

    resultArray.push({
      packageName
    });
  }

  return resultArray;
};
//# sourceMappingURL=index.js.map